==> haskell-hasql-transaction-1.0.1.1-403-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-transaction.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-transaction
version:              1.0.1.1
visibility:           public
id:                   hasql-transaction-1.0.1.1-GMxiJe4jjCBsdjziChMD4
key:                  hasql-transaction-1.0.1.1-GMxiJe4jjCBsdjziChMD4
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-transaction
synopsis:
    Composable abstraction over retryable transactions for Hasql

category:             Hasql, Database, PostgreSQL
abi:                  780602d3435bcc0deb8925f301dc9d63
exposed:              True
exposed-modules:      Hasql.Transaction Hasql.Transaction.Sessions
hidden-modules:
    Hasql.Transaction.Private.Prelude Hasql.Transaction.Private.Model
    Hasql.Transaction.Private.SQL Hasql.Transaction.Private.Statements
    Hasql.Transaction.Private.Sessions
    Hasql.Transaction.Private.Transaction

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hasql-transaction-1.0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hasql-transaction-1.0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hasql-transaction-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-transaction
hs-libraries:         HShasql-transaction-1.0.1.1-GMxiJe4jjCBsdjziChMD4
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    bytestring-tree-builder-0.2.7.13-LxrCRd0deuvIzOgEIz6Pj5
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    contravariant-extras-0.3.5.4-55ftugxfRMl5DZHT7luCXJ
    hasql-1.5.0.5-GfbqGOi0yv1ACsS8skVOLS mtl-2.2.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hasql-transaction/html/hasql-transaction.haddock

haddock-html:         /usr/share/doc/haskell-hasql-transaction/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-transaction-1.0.1.1-404-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-transaction.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-transaction
version:              1.0.1.1
visibility:           public
id:                   hasql-transaction-1.0.1.1-DypsHOBrPKGIS2g0zrdWHF
key:                  hasql-transaction-1.0.1.1-DypsHOBrPKGIS2g0zrdWHF
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-transaction
synopsis:
    Composable abstraction over retryable transactions for Hasql

category:             Hasql, Database, PostgreSQL
abi:                  084bba75c624def3b76dff361e49ab27
exposed:              True
exposed-modules:      Hasql.Transaction Hasql.Transaction.Sessions
hidden-modules:
    Hasql.Transaction.Private.Prelude Hasql.Transaction.Private.Model
    Hasql.Transaction.Private.SQL Hasql.Transaction.Private.Statements
    Hasql.Transaction.Private.Sessions
    Hasql.Transaction.Private.Transaction

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hasql-transaction-1.0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hasql-transaction-1.0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hasql-transaction-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-transaction
hs-libraries:         HShasql-transaction-1.0.1.1-DypsHOBrPKGIS2g0zrdWHF
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    bytestring-tree-builder-0.2.7.13-4aAOLIGwTeZ1vNcxKDPV3m
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    contravariant-extras-0.3.5.4-55ftugxfRMl5DZHT7luCXJ
    hasql-1.5.0.5-Fci8wJskVqq6Cp61LB0MKh mtl-2.2.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hasql-transaction/html/hasql-transaction.haddock

haddock-html:         /usr/share/doc/haskell-hasql-transaction/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
